#! /bin/bash

RESQUDIR=./ResQu
OTHERDIR=./OtherTools
INPUT=$2
MODE=$1
VERSION=ResQu_v2 #for long-distance resolution please use ResQu_lp instead

# IMPORTANT: please make sure you have chosen correct mode, 
# corresponding files exist and have valid formats.

# --------------------- tools description -----------------------
# for AM heuristics just add "-alter 1" flag for RESQU below

# Squolem false proof
	if [ $MODE == 0 ]; then
		RESQU="$RESQUDIR/$VERSION "
		QDIMACSTOBLIF="$OTHERDIR/false_qdimacs_to_blif "
		readonly proof=$INPUT
		readonly certificate=$INPUT.blif  # "_am1.blif" for AM heuristics
		readonly qbfblif=${INPUT%.qdimacs}.blif
		combined=$INPUT.combined.blif ;
	fi
# Qube-cert false proof
	if [ $MODE == 1 ]; then
		RESQU="$RESQUDIR/$VERSION -m 1 "
		QDIMACSTOBLIF="$OTHERDIR/qube_false_qbf_to_blif "
		SUFFIX=.simp.qrp     #change to the suffix you are using, if it is not the same
		readonly proof=$INPUT
		readonly certificate=$INPUT.blif  # "_am1.blif" for AM heuristics
		readonly qbfblif=${proof%$SUFFIX}.blif
		combined=$INPUT.combined.blif ;
	fi
# Qube-cert true proof
	if [ $MODE == 2 ]; then
		RESQU="$RESQUDIR/$VERSION -m 2 " 
		QDIMACSTOBLIF="$OTHERDIR/qube_true_qbf_to_blif "
		SUFFIX=.simp.qrp     #change to the suffix you are using, if it is not the same
		readonly proof=$INPUT
		readonly certificate=$INPUT.blif  # "_am1.blif" for AM heuristics
		readonly qbfblif=${proof%$SUFFIX}.blif
		combined=$INPUT.combined.blif ;
	fi	
# DepQBF false proof
	if [ $MODE == 3 ]; then
		RESQU="$RESQUDIR/$VERSION -m 3 "  
		QDIMACSTOBLIF="$OTHERDIR/false_qdimacs_to_blif " 
		SUFFIX=.core.qrp     #change to ".qrp" if using DepQBF non-core proof
		readonly proof=${INPUT%$SUFFIX}  
		readonly certificate=$INPUT.blif  # "_am1.blif" for AM heuristics
		readonly qbfblif=${proof%.qdimacs}.blif 
		combined=$INPUT.combined.blif ;
	fi	
# DepQBF true proof
	if [ $MODE == 4 ]; then
		RESQU="$RESQUDIR/$VERSION -m 4 -nomyqrp " 
		QDIMACSTOBLIF="$OTHERDIR/true_qdimacs_to_blif "
		SUFFIX=.core.qrp     #change to ".qrp" if using DepQBF non-core proof
		readonly proof=${INPUT%$SUFFIX}
		readonly certificate=$INPUT.blif  # "_am1.blif" for AM heuristics
		readonly qbfblif=${proof%.qdimacs}.blif
		combined=$INPUT.combined.blif ;
	fi
COMBINE="$OTHERDIR/combine_proof_certificate_blifs "
# ------------------------------------------------------------------

# 1: run ResQu
	echo " ****  Running ResQu  ****"
	$RESQU $INPUT

# 2: run certificate verification 
	echo " ****  Converting QBF into blif  ****" 
	$QDIMACSTOBLIF $proof
	echo " "
	
	echo " ****  Combining proof and certificate  ****"
	$COMBINE $qbfblif $certificate $combined
	echo " "

# NOTICE: To print stats or verify certificates, you should run this script within ABC home directory	

	echo " ****  Running ABC to check certificate ****"
	#exec ./abc -c "r $certificate ; st ; ps "   # to print the certificate size
	#exec ./abc -c "r $certificate ; st ; balance ; ps "   # to print the certificate size after balancing
	exec ./abc -c "r $combined ; st ; sat "     # original SAT solving by ABC
	#exec ./abc -c "r $combined ; st ; balance ; sat "     # SAT solving by ABC after balancing 

exit 0
